@@ -1,9 +1,9 @@
 #!/bin/sh
-# COPYRIGHT (C) HITACHI,LTD. 2003 ALL RIGHTS RESERVED. 
+# COPYRIGHT (C) HITACHI,LTD. 2003-2004
 # Written by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>
 
 LKSTMAJ=`cat /proc/devices | grep lkst | cut -f 1 -d " "`
-if [ -z "$LSKTMAJ" ] ; then 
+if [ -z "$LKSTMAJ" ] ; then 
 echo "Error: Run after enabled lkst."
 exit 0
 fi
