@@ -1,13 +1,22 @@
 #!/bin/sh
 # LKST release package script
-# COPYRIGHT (C) HITACHI,LTD. 2003 ALL RIGHTS RESERVED. 
+# COPYRIGHT (C) HITACHI,LTD. 2003-2004
 # Written by M.Hiramatsu <hiramatu@sdl.hitachi.co.jp>
 # Usage: scripts/release [clean]
 # !WARNIG!: you should check following 2 points before using this script.
 # 1. Make sure that /usr/src/linux points the kernel patched release-version patches of LKST.
 # 2. Make sure that you can build rpm packages.
 
-[ -z "$RELDIR" ] && RELDIR=Releases
+SCRDIR=`dirname $0`
+[ "$SCRDIR" ] || SCRDIR=`pwd`
+source $SCRDIR/../lkst.version
+source $SCRDIR/functions
+
+SCRDIR=`rp2ap $SCRDIR`
+ROOTDIR=`rp2ap $SCRDIR/../`
+PATCHDIR=$ROOTDIR/patches
+
+RELDIR=$ROOTDIR/Releases
 LOGFILE=$RELDIR/release.log
 
 if [ "$1" = clean ] ; then
@@ -19,45 +28,43 @@ if [ "$1" = clean ] ; then
 fi
 
 [ -e $RELDIR ] && echo "$RELDIR already exists, abort." && exit 1
-
 mkdir $RELDIR
-eval `grep ^VERSION Makefile | tr -d " " ` 
 
 echo -n "compressing patches ..."
-( cp linux26.patch $RELDIR/lkst-$VERSION.linux26.patch ;
-#  cp lkcd-addon/*.patch ./$RELDIR ;
-  cp hooks/*.patch ./$RELDIR ;
-  cp extra-patch/*.patch ./$RELDIR ;
+( cp $PATCHDIR/*.patch $RELDIR ;
   gzip -f $RELDIR/*.patch 
   ) &> $LOGFILE
 if [ $? -ne 0 ]; then echo "failed" ; exit 1; fi
+mv $RELDIR/linux26.patch.gz $RELDIR/lkst-$VERSION.linux26.patch.gz
 echo "done"
 
 echo -n "converting documents ..."
-( nkf --windows Install > $RELDIR/Install-$VERSION.txt
-  nkf --windows howto.txt > $RELDIR/Howto-$VERSION.txt
-  nkf --windows changelog > $RELDIR/Changelog-$VERSION.txt
+( nkf --windows $ROOTDIR/Install > $RELDIR/Install-$VERSION.txt
+  nkf --windows $ROOTDIR/howto.txt > $RELDIR/Howto-$VERSION.txt
+  nkf --windows $ROOTDIR/changelog > $RELDIR/Changelog-$VERSION.txt
   ) >> $LOGFILE 2>&1
 if [ $? -ne 0 ]; then echo "failed" ; exit 1; fi
 echo "done"
 
 echo -n "configuring packages ..."
-make config KSRC=/usr/src/linux >> $LOGFILE  2>&1
+( cd $ROOTDIR
+  make config 
+  ) >> $LOGFILE  2>&1
 if [ $? -ne 0 ]; then echo "failed" ; exit 1; fi
 echo "done"
 
 echo -n "packaging lkstutils ..."
-( cd command
+( cd $ROOTDIR/lkstutils
   make dist
-  mv lkstutils-*.tar.gz ../$RELDIR/
+  mv lkstutils-*.tar.gz $RELDIR/
   ) >> $LOGFILE 2>&1
 if [ $? -ne 0 ]; then echo "failed" ; exit 1; fi
 echo "done"
 
 echo -n "packaging lkstaddons ..."
-( cd addons
+( cd $ROOTDIR/lkstaddons
   make dist
-  mv lkstaddons-*.tar.gz ../$RELDIR/
+  mv lkstaddons-*.tar.gz $RELDIR/
   ) >> $LOGFILE 2>&1
 if [ $? -ne 0 ]; then echo "failed" ; exit 1; fi
 echo "done"
@@ -67,13 +74,15 @@ echo -n "building the rpm package of lkstutils ..."
   echo See $RELDIR/rpm.log
   rpmbuild -ta $RELDIR/lkstutils-*.tar.gz &> $RELDIR/rpm.log
   [ $? -eq 0 ] && mv `grep ^Wrote $RELDIR/rpm.log | cut -d" " -f2 ` $RELDIR
- ) >> $LOGFILE 2>&1
+  ) >> $LOGFILE 2>&1
 if [ $? -ne 0 ]; then echo "failed" ; exit 1; fi
 echo "done"
 
 echo -n "packaging lkst ..."
-make dist >> $LOGFILE 2>&1
-mv lkst-*.tar.gz $RELDIR/
+( cd $ROOTDIR
+  make dist
+  mv lkst-*.tar.gz $RELDIR/
+  ) >> $LOGFILE 2>&1
 if [ $? -ne 0 ]; then echo "failed" ; exit 1; fi
 echo "done"
 
